package com.example.switchyard.switchyard_example;

import javax.inject.Inject;

import org.apache.camel.component.netty.NettyConsumer;
import org.apache.camel.component.netty.NettyHelper;
import org.apache.camel.component.netty.handlers.ServerChannelHandler;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.channel.ChannelStateEvent;
import org.jboss.netty.channel.ExceptionEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.switchyard.component.bean.Reference;

public class MyServerHandler extends ServerChannelHandler{

    private NettyConsumer consumer;
    private static final transient Logger LOG = LoggerFactory.getLogger(NettyConsumer.class);

    @Inject
    @Reference
    Hello helloBean;
    
	public MyServerHandler(NettyConsumer consumer) {
		super(consumer);
		consumer = consumer;
	}

	 @Override
	    public void channelOpen(ChannelHandlerContext ctx, ChannelStateEvent e) throws Exception {
	        if (LOG.isTraceEnabled()) {
	            LOG.trace("Channel open: {}", e.getChannel());
	        }
	        System.out.println();
	        
	        
	        helloBean.hello("Client connected");
	    }

	    @Override
	    public void channelClosed(ChannelHandlerContext ctx, ChannelStateEvent e) throws Exception {
	        if (LOG.isTraceEnabled()) {
	            LOG.trace("Channel closed: {}", e.getChannel());
	        }
	      
	        
	        helloBean.hello("Client disconnected");

	    }

	    @Override
	    public void exceptionCaught(ChannelHandlerContext ctx, ExceptionEvent exceptionEvent) throws Exception {
	        // only close if we are still allowed to run
	        if (consumer.isRunAllowed()) {
	            LOG.warn("Closing channel as an exception was thrown from Netty", exceptionEvent.getCause());

	            // close channel in case an exception was thrown
	            NettyHelper.close(exceptionEvent.getChannel());
	        }
	    }
	
}
